@@ -1,3 +1,23 @@
+__copyright__ = """
+
+    Copyright 2019 Samapriya Roy
+
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
+
+"""
+__license__ = "Apache 2.0"
+
+
 import requests
 import time
 import progressbar
@@ -5,9 +25,9 @@ import json
 import os
 import sys
 import csv
+from retrying import retry
 from planet.api.utils import read_planet_json
 from planet.api.auth import find_api_key
-os.chdir(os.path.dirname(os.path.realpath(__file__)))
 
 #Get Planet API and Authenticate SESSION
 try:
@@ -19,23 +39,26 @@ SESSION = requests.Session()
 SESSION.auth = (PL_API_KEY, '')
 
 # To get redirect link
+@retry(
+    wait_exponential_multiplier=1000,
+    wait_exponential_max=10000)
 def check_for_redirects(url):
     try:
         r = SESSION.get(url, allow_redirects=False, timeout=0.5)
         if 300 <= r.status_code < 400:
             return r.headers['location']
-        else:
-            return 'no redirect'
+        elif r.status_code==429:
+            raise Exception("rate limit error")
     except requests.exceptions.Timeout:
         return '[timeout]'
     except requests.exceptions.ConnectionError:
         return '[connection error]'
+    except requests.HTTPError as e:
+        if r.status_code == 429:  # Too many requests
+            raise Exception("rate limit error")
 
 #Get the redirects and download
-def download(url,local,errorlog):
-    with open(errorlog,'wb') as csvfile:
-        writer=csv.DictWriter(csvfile,fieldnames=["id_no"], delimiter=',')
-        writer.writeheader()
+def download(url,local,ext):
     response=SESSION.get(url).json()
     print("Polling ...")
     while response['state']=='running' or response['state']=='starting':
@@ -53,19 +76,24 @@ def download(url,local,errorlog):
                 local_path=os.path.join(local,str(os.path.split(items['name'])[-1]))
                 result=SESSION.get(redirect_url)
                 if not os.path.exists(local_path) and result.status_code==200:
-                    print("Downloading: " + str(local_path))
-                    f = open(local_path, 'wb')
-                    for chunk in result.iter_content(chunk_size=512 * 1024):
-                        if chunk:
-                            f.write(chunk)
-                    f.close()
+                    if ext is not None:
+                        if local_path.endswith(ext):
+                            print("Downloading: " + str(local_path))
+                            f = open(local_path, 'wb')
+                            for chunk in result.iter_content(chunk_size=512 * 1024):
+                                if chunk:
+                                    f.write(chunk)
+                            f.close()
+                    elif ext is None:
+                        print("Downloading: " + str(local_path))
+                        f = open(local_path, 'wb')
+                        for chunk in result.iter_content(chunk_size=512 * 1024):
+                            if chunk:
+                                f.write(chunk)
+                        f.close()
                 else:
                     if int(result.status_code)!=200:
                         print("Encountered error with code: " + str(result.status_code)+' for '+str(os.path.split(items['name'])[-1]))
-                        with open(errorlog,'a') as csvfile:
-                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
-                            writer.writerow([str(os.path.split(items['name'])[-1])])
-                        csvfile.close()
                     elif int(result.status_code)==200:
                         print("File already exists SKIPPING: "+str(os.path.split(items['name'])[-1]))
     else:
